@@ -491,17 +491,24 @@ class SecurityIndicatorsAggregator:
     si_cloc = SecurityIndicatorsCloc()
 
     def create_si_aggregated_dataframe(
-        self, si_bandit_report: Dict[str, Any], si_cloc_report: Dict[str, Any]
+        self,
+        si_bandit_report: Dict[str, Any],
+        si_cloc_report: Dict[str, Any],
+        filters_files: Optional[List[str]] = None,
     ) -> pd.DataFrame:
         """Create dataframe with aggregated data from SI analyzers.
 
         :param si_bandit_report: SI bandit report provided by Thoth SI bandit analyzer.
         :param si_cloc_report: SI cloc report provided by Thoth SI cloc analyzer.
+        :param filters_files: List of strings of files to be filtered from analysis
+        e.g. filter_files = ['/tests'] where /tests is filtered in the file path.
 
         :output aggregated_df: pandas.DataFrame aggregating all SI analyzers reports provided.
         """
         aggregated_df = pd.DataFrame()
-        si_bandit_df = self.si_bandit.create_si_bandit_final_dataframe(si_bandit_report=si_bandit_report)
+        si_bandit_df = self.si_bandit.create_si_bandit_final_dataframe(
+            si_bandit_report=si_bandit_report, filters_files=filters_files
+        )
         si_cloc_df = self.si_cloc.create_si_cloc_final_dataframe(si_cloc_report=si_cloc_report)
 
         package_info = ["package_name", "package_version", "package_index"]
@@ -525,17 +532,22 @@ class SecurityIndicatorsAggregator:
         return aggregated_df
 
     def create_si_aggregated_json(
-        self, si_bandit_report: Dict[str, Any], si_cloc_report: Dict[str, Any]
+        self,
+        si_bandit_report: Dict[str, Any],
+        si_cloc_report: Dict[str, Any],
+        filters_files: Optional[List[str]] = None,
     ) -> Dict[str, Any]:
         """Create json with aggregated data from SI analyzers.
 
         :param si_bandit_report: SI bandit report provided by Thoth SI bandit analyzer.
         :param si_cloc_report: SI cloc report provided by Thoth SI cloc analyzer.
+        :param filters_files: List of strings of files to be filtered from analysis
+        e.g. filter_files = ['/tests'] where /tests is filtered in the file path.
 
         :output: json file with aggregated SI analyzers reports provided.
         """
         aggregated_df = self.create_si_aggregated_dataframe(
-            si_bandit_report=si_bandit_report, si_cloc_report=si_cloc_report
+            si_bandit_report=si_bandit_report, si_cloc_report=si_cloc_report, filters_files=filters_files
         )
         aggregated_si = aggregated_df.to_json(orient="records")  # string
 
